@@ -7,7 +7,7 @@
 #  define VTKPVANIMATION_NO_EXPORT
 #else
 #  ifndef VTKPVANIMATION_EXPORT
-#    ifdef vtkPVAnimation_EXPORTS
+#    ifdef Animation_EXPORTS
         /* We are building this library */
 #      define VTKPVANIMATION_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,20 @@
 
 #ifndef VTKPVANIMATION_DEPRECATED
 #  define VTKPVANIMATION_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVANIMATION_DEPRECATED_EXPORT VTKPVANIMATION_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVANIMATION_DEPRECATED_NO_EXPORT VTKPVANIMATION_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVANIMATION_NO_DEPRECATED
+#ifndef VTKPVANIMATION_DEPRECATED_EXPORT
+#  define VTKPVANIMATION_DEPRECATED_EXPORT VTKPVANIMATION_EXPORT VTKPVANIMATION_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkPVServerManagerCoreModule.h"
-#include "vtkPVVTKExtensionsDefaultModule.h"
-
+#ifndef VTKPVANIMATION_DEPRECATED_NO_EXPORT
+#  define VTKPVANIMATION_DEPRECATED_NO_EXPORT VTKPVANIMATION_NO_EXPORT VTKPVANIMATION_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVANIMATION_NO_DEPRECATED
+#    define VTKPVANIMATION_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVANIMATION_EXPORT_H */
