@@ -7,7 +7,7 @@
 #  define VTKPVPYTHONALGORITHM_NO_EXPORT
 #else
 #  ifndef VTKPVPYTHONALGORITHM_EXPORT
-#    ifdef vtkPVPythonAlgorithm_EXPORTS
+#    ifdef PythonAlgorithm_EXPORTS
         /* We are building this library */
 #      define VTKPVPYTHONALGORITHM_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKPVPYTHONALGORITHM_DEPRECATED
 #  define VTKPVPYTHONALGORITHM_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVPYTHONALGORITHM_DEPRECATED_EXPORT VTKPVPYTHONALGORITHM_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVPYTHONALGORITHM_DEPRECATED_NO_EXPORT VTKPVPYTHONALGORITHM_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVPYTHONALGORITHM_NO_DEPRECATED
+#ifndef VTKPVPYTHONALGORITHM_DEPRECATED_EXPORT
+#  define VTKPVPYTHONALGORITHM_DEPRECATED_EXPORT VTKPVPYTHONALGORITHM_EXPORT VTKPVPYTHONALGORITHM_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkPVServerImplementationCoreModule.h"
-
+#ifndef VTKPVPYTHONALGORITHM_DEPRECATED_NO_EXPORT
+#  define VTKPVPYTHONALGORITHM_DEPRECATED_NO_EXPORT VTKPVPYTHONALGORITHM_NO_EXPORT VTKPVPYTHONALGORITHM_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVPYTHONALGORITHM_NO_DEPRECATED
+#    define VTKPVPYTHONALGORITHM_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVPYTHONALGORITHM_EXPORT_H */
