@@ -7,7 +7,7 @@
 #  define VTKPVSERVERMANAGERAPPLICATION_NO_EXPORT
 #else
 #  ifndef VTKPVSERVERMANAGERAPPLICATION_EXPORT
-#    ifdef vtkPVServerManagerApplication_EXPORTS
+#    ifdef ServerManagerApplication_EXPORTS
         /* We are building this library */
 #      define VTKPVSERVERMANAGERAPPLICATION_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKPVSERVERMANAGERAPPLICATION_DEPRECATED
 #  define VTKPVSERVERMANAGERAPPLICATION_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVSERVERMANAGERAPPLICATION_DEPRECATED_EXPORT VTKPVSERVERMANAGERAPPLICATION_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVSERVERMANAGERAPPLICATION_DEPRECATED_NO_EXPORT VTKPVSERVERMANAGERAPPLICATION_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVSERVERMANAGERAPPLICATION_NO_DEPRECATED
+#ifndef VTKPVSERVERMANAGERAPPLICATION_DEPRECATED_EXPORT
+#  define VTKPVSERVERMANAGERAPPLICATION_DEPRECATED_EXPORT VTKPVSERVERMANAGERAPPLICATION_EXPORT VTKPVSERVERMANAGERAPPLICATION_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkPVServerManagerCoreModule.h"
-
+#ifndef VTKPVSERVERMANAGERAPPLICATION_DEPRECATED_NO_EXPORT
+#  define VTKPVSERVERMANAGERAPPLICATION_DEPRECATED_NO_EXPORT VTKPVSERVERMANAGERAPPLICATION_NO_EXPORT VTKPVSERVERMANAGERAPPLICATION_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVSERVERMANAGERAPPLICATION_NO_DEPRECATED
+#    define VTKPVSERVERMANAGERAPPLICATION_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVSERVERMANAGERAPPLICATION_EXPORT_H */
