@@ -7,7 +7,7 @@
 #  define VTKPVVTKEXTENSIONSCGNSREADER_NO_EXPORT
 #else
 #  ifndef VTKPVVTKEXTENSIONSCGNSREADER_EXPORT
-#    ifdef vtkPVVTKExtensionsCGNSReader_EXPORTS
+#    ifdef VTKExtensionsCGNSReader_EXPORTS
         /* We are building this library */
 #      define VTKPVVTKEXTENSIONSCGNSREADER_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED
 #  define VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSCGNSREADER_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSCGNSREADER_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVVTKEXTENSIONSCGNSREADER_NO_DEPRECATED
+#ifndef VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED_EXPORT
+#  define VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSCGNSREADER_EXPORT VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkPVVTKExtensionsCoreModule.h"
-
+#ifndef VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED_NO_EXPORT
+#  define VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSCGNSREADER_NO_EXPORT VTKPVVTKEXTENSIONSCGNSREADER_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVVTKEXTENSIONSCGNSREADER_NO_DEPRECATED
+#    define VTKPVVTKEXTENSIONSCGNSREADER_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVVTKEXTENSIONSCGNSREADER_EXPORT_H */
