@@ -7,7 +7,7 @@
 #  define VTKPVVTKEXTENSIONSDEFAULT_NO_EXPORT
 #else
 #  ifndef VTKPVVTKEXTENSIONSDEFAULT_EXPORT
-#    ifdef vtkPVVTKExtensionsDefault_EXPORTS
+#    ifdef VTKExtensionsDefault_EXPORTS
         /* We are building this library */
 #      define VTKPVVTKEXTENSIONSDEFAULT_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,25 +23,20 @@
 
 #ifndef VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED
 #  define VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSDEFAULT_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSDEFAULT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVVTKEXTENSIONSDEFAULT_NO_DEPRECATED
+#ifndef VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED_EXPORT
+#  define VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSDEFAULT_EXPORT VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersExtractionModule.h"
-#include "vtkFiltersGeneralModule.h"
-#include "vtkFiltersParallelFlowPathsModule.h"
-#include "vtkIOImportModule.h"
-#include "vtkIOMPIImageModule.h"
-#include "vtkIOParallelModule.h"
-#include "vtkIOParallelExodusModule.h"
-#include "vtkInteractionWidgetsModule.h"
-#include "vtkPVVTKExtensionsCoreModule.h"
-#include "vtkPVVTKExtensionsRenderingModule.h"
-
+#ifndef VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED_NO_EXPORT
+#  define VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSDEFAULT_NO_EXPORT VTKPVVTKEXTENSIONSDEFAULT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVVTKEXTENSIONSDEFAULT_NO_DEPRECATED
+#    define VTKPVVTKEXTENSIONSDEFAULT_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVVTKEXTENSIONSDEFAULT_EXPORT_H */
