@@ -7,7 +7,7 @@
 #  define VTKPVVTKEXTENSIONSPOINTS_NO_EXPORT
 #else
 #  ifndef VTKPVVTKEXTENSIONSPOINTS_EXPORT
-#    ifdef vtkPVVTKExtensionsPoints_EXPORTS
+#    ifdef VTKExtensionsPoints_EXPORTS
         /* We are building this library */
 #      define VTKPVVTKEXTENSIONSPOINTS_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKPVVTKEXTENSIONSPOINTS_DEPRECATED
 #  define VTKPVVTKEXTENSIONSPOINTS_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKPVVTKEXTENSIONSPOINTS_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSPOINTS_EXPORT __attribute__ ((__deprecated__))
-#  define VTKPVVTKEXTENSIONSPOINTS_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSPOINTS_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKPVVTKEXTENSIONSPOINTS_NO_DEPRECATED
+#ifndef VTKPVVTKEXTENSIONSPOINTS_DEPRECATED_EXPORT
+#  define VTKPVVTKEXTENSIONSPOINTS_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSPOINTS_EXPORT VTKPVVTKEXTENSIONSPOINTS_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersPointsModule.h"
-
+#ifndef VTKPVVTKEXTENSIONSPOINTS_DEPRECATED_NO_EXPORT
+#  define VTKPVVTKEXTENSIONSPOINTS_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSPOINTS_NO_EXPORT VTKPVVTKEXTENSIONSPOINTS_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKPVVTKEXTENSIONSPOINTS_NO_DEPRECATED
+#    define VTKPVVTKEXTENSIONSPOINTS_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKPVVTKEXTENSIONSPOINTS_EXPORT_H */
