@@ -15,7 +15,6 @@
 //=============================================================================
 #ifndef vtkmlib_ImplicitFunctionConverter_h
 #define vtkmlib_ImplicitFunctionConverter_h
-#ifndef __VTK_WRAP__
 
 #include "vtkAcceleratorsVTKmModule.h"
 #include "vtkmConfig.h" //required for general vtkm setup
@@ -43,5 +42,4 @@ private:
 
 }
 
-#endif
 #endif // vtkmlib_ImplicitFunctionConverter_h
