@@ -32,7 +32,7 @@
   #define XDMF_BYTE_ORDER_LITTLE
 #endif
 
-#define XDMF_SYSTEM Linux-5.2.1-arch1-1-ARCH
+#define XDMF_SYSTEM Linux-5.4.1-arch1-1
 
 #define XDMF_VOID_VALID
 #ifndef XDMF_VOID_VALID
